from unbrowsed.parser import parse_html
from unbrowsed.queries import query_by_label_text, MultipleElementsFoundError

__version__ = "0.1.0"
__all__ = ["parse_html", "query_by_label_text", "MultipleElementsFoundError"]
